@@ -38,6 +38,10 @@ func trimDb(ctx context.Context, namespace string) ([]string, error) {
 	return cachedb.Trim(ctx, namespace)
 }
 
+func flushDb(ctx context.Context, namespace string) ([]string, error) {
+	return cachedb.Flush(ctx, namespace)
+}
+
 func CloseDb() {
 	cachedb.CloseDb()
 }
