@@ -50,8 +50,10 @@ func Chdir(p *lang.Process, path string) error {
 	switch pwdHist.(type) {
 	case []string:
 		pwdHist = append(pwdHist.([]string), pwd)
+	case []interface{}:
+		pwdHist = append(pwdHist.([]interface{}), pwd)
 	default:
-		debug.Log(fmt.Sprintf("$%s has become corrupt (%t) so regenerating", GlobalVarName, pwdHist))
+		debug.Log(fmt.Sprintf("$%s has become corrupt (%T) so regenerating", GlobalVarName, pwdHist))
 		pwdHist = []string{pwd}
 	}
 
